FileReader
==========

.. currentmodule:: hdfs_native

.. autoclass:: FileReader
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~FileReader.size

   .. rubric:: Methods Summary

   .. autosummary::

      ~FileReader.close
      ~FileReader.read
      ~FileReader.read_range
      ~FileReader.readable
      ~FileReader.readall
      ~FileReader.seek
      ~FileReader.seekable
      ~FileReader.tell

   .. rubric:: Attributes Documentation

   .. autoattribute:: size

   .. rubric:: Methods Documentation

   .. automethod:: close
   .. automethod:: read
   .. automethod:: read_range
   .. automethod:: readable
   .. automethod:: readall
   .. automethod:: seek
   .. automethod:: seekable
   .. automethod:: tell
